@@ -1,9 +1,8 @@
 # rasterio
+from __future__ import absolute_import
 
 from collections import namedtuple
 import logging
-import os
-import warnings
 
 from rasterio._base import eval_window, window_shape, window_index
 from rasterio._drivers import driver_count, GDALEnv
@@ -14,6 +13,7 @@ from rasterio.dtypes import (
 from rasterio.five import string_types
 from rasterio.profiles import default_gtiff_profile
 from rasterio.transform import Affine, guard_transform
+from rasterio import windows
 
 # These modules are imported from the Cython extensions, but are also import
 # here to help tools like cx_Freeze find them automatically
@@ -23,7 +23,7 @@ from rasterio import _err, coords, enums, vfs
 
 __all__ = [
     'band', 'open', 'drivers', 'copy', 'pad']
-__version__ = "0.32.0"
+__version__ = "0.33.0"
 
 log = logging.getLogger('rasterio')
 class NullHandler(logging.Handler):
@@ -33,7 +33,7 @@ log.addHandler(NullHandler())
 
 
 def open(
-        path, mode='r', 
+        path, mode='r',
         driver=None,
         width=None, height=None,
         count=None,
@@ -43,7 +43,7 @@ def open(
         **kwargs):
     """Open file at ``path`` in ``mode`` "r" (read), "r+" (read/write),
     or "w" (write) and return a ``Reader`` or ``Updater`` object.
-    
+
     In write mode, a driver name such as "GTiff" or "JPEG" (see GDAL
     docs or ``gdal_translate --help`` on the command line), ``width``
     (number of pixels per line) and ``height`` (number of lines), the
@@ -52,41 +52,89 @@ def open(
     8-bit bands or ``rasterio.uint16`` for 16-bit bands must be
     specified using the ``dtype`` argument.
 
+    Parameters
+    ----------
+    mode: string
+        "r" (read), "r+" (read/write), or "w" (write)
+    driver: string
+        driver code specifying the format name (e.g. "GTiff" or "JPEG")
+        See GDAL docs at http://www.gdal.org/formats_list.html
+        (optional, required for write)
+    width: int
+        number of pixels per line
+        (optional, required for write)
+    height: int
+        number of lines
+        (optional, required for write)
+    count: int > 0
+        number of bands
+        (optional, required for write)
+    dtype: rasterio.dtype
+        the data type for bands such as ``rasterio.ubyte`` for
+        8-bit bands or ``rasterio.uint16`` for 16-bit bands
+        (optional, required for write)
+    crs: dict or string
+        Coordinate reference system
+        (optional, recommended for write)
+    transform: Affine instance
+        Affine transformation mapping the pixel space to geographic space
+        (optional, recommended for write)
+    nodata: number
+        Defines pixel value to be interpreted as null/nodata
+        (optional, recommended for write)
+
+    Returns
+    -------
+    A ``Reader`` or ``Updater`` object.
+
+    Notes
+    -----
+    In write mode, you must specify at least ``width``, ``height``, ``count``
+    and ``dtype``.
+
     A coordinate reference system for raster datasets in write mode can
     be defined by the ``crs`` argument. It takes Proj4 style mappings
     like
-    
-      {'proj': 'longlat', 'ellps': 'WGS84', 'datum': 'WGS84',
-       'no_defs': True}
+
+    .. code::
+
+      {'proj': 'longlat', 'ellps': 'WGS84', 'datum': 'WGS84', 'no_defs': True}
 
     An affine transformation that maps ``col,row`` pixel coordinates to
     ``x,y`` coordinates in the coordinate reference system can be
-    specified using the ``transform`` argument. The value may be either
-    an instance of ``affine.Affine`` or a 6-element sequence of the
-    affine transformation matrix coefficients ``a, b, c, d, e, f``.
+    specified using the ``transform`` argument. The value should be
+    an instance of ``affine.Affine``
+
+    .. code:: python
+
+        >>> from affine import Affine
+        >>> Affine(0.5, 0.0, -180.0, 0.0, -0.5, 90.0)
+
     These coefficients are shown in the figure below.
 
+    .. code::
+
       | x |   | a  b  c | | c |
       | y | = | d  e  f | | r |
       | 1 |   | 0  0  1 | | 1 |
 
-    a: rate of change of X with respect to increasing column, i.e.
-            pixel width
-    b: rotation, 0 if the raster is oriented "north up" 
-    c: X coordinate of the top left corner of the top left pixel 
-    f: Y coordinate of the top left corner of the top left pixel 
-    d: rotation, 0 if the raster is oriented "north up"
-    e: rate of change of Y with respect to increasing row, usually
-            a negative number i.e. -1 * pixel height
-    f: Y coordinate of the top left corner of the top left pixel 
+        a: rate of change of X with respect to increasing column, i.e.  pixel width
+        b: rotation, 0 if the raster is oriented "north up"
+        c: X coordinate of the top left corner of the top left pixel
+        d: rotation, 0 if the raster is oriented "north up"
+        e: rate of change of Y with respect to increasing row, usually
+                a negative number (i.e. -1 * pixel height) if north-up.
+        f: Y coordinate of the top left corner of the top left pixel
+
+    A 6-element sequence of the affine transformation
+    matrix coefficients in ``c, a, b, f, d, e`` order,
+    (i.e. GDAL geotransform order) will be accepted until 1.0 (deprecated).
 
     A virtual filesystem can be specified. The ``vfs`` parameter may be
     an Apache Commons VFS style string beginning with "zip://" or
     "tar://"". In this case, the ``path`` must be an absolute path
     within that container.
 
-    Finally, additional kwargs are passed to GDAL as driver-specific
-    dataset creation parameters.
     """
     if not isinstance(path, string_types):
         raise TypeError("invalid path: %r" % path)
@@ -125,14 +173,30 @@ def open(
 
 
 def copy(src, dst, **kw):
-    """Copy a source dataset to a new destination with driver specific
+    """Copy a source raster to a new destination with driver specific
     creation options.
 
-    ``src`` must be an existing file and ``dst`` a valid output file.
+    Parameters
+    ----------
+    src: string
+        an existing raster file
+    dst: string
+        valid path to output file.
 
+    Returns
+    -------
+    None
+
+    Raises
+    ------
+    ValueError:
+        If source path is not a valid Dataset
+
+    Notes
+    -----
     A ``driver`` keyword argument with value like 'GTiff' or 'JPEG' is
     used to control the output format.
-    
+
     This is the one way to create write-once files like JPEGs.
     """
     from rasterio._copy import RasterCopier
@@ -141,30 +205,74 @@ def copy(src, dst, **kw):
 
 
 def drivers(**kwargs):
-    """Returns a gdal environment with registered drivers."""
-    if driver_count() == 0:
-        log.debug("Creating a chief GDALEnv in drivers()")
-        return GDALEnv(True, **kwargs)
-    else:
-        log.debug("Creating a not-responsible GDALEnv in drivers()")
-        return GDALEnv(False, **kwargs)
+    """Create a gdal environment with registered drivers and
+    creation options.
+
+    Parameters
+    ----------
+    **kwargs:: keyword arguments
+        Configuration options that define GDAL driver behavior
+
+        See https://trac.osgeo.org/gdal/wiki/ConfigOptions
+
+    Returns
+    -------
+    GDALEnv responsible for managing the environment.
+
+    Notes
+    -----
+    Use as a context manager, ``with rasterio.drivers(): ...``
+    """
+    return GDALEnv(**kwargs)
 
 
 Band = namedtuple('Band', ['ds', 'bidx', 'dtype', 'shape'])
 
 def band(ds, bidx):
-    """Wraps a dataset and a band index up as a 'Band'"""
+    """Wraps a dataset and a band index up as a 'Band'
+
+    Parameters
+    ----------
+    ds: rasterio.RasterReader
+        Open rasterio dataset
+    bidx: int
+        Band number, index starting at 1
+
+    Returns
+    -------
+    a rasterio.Band
+    """
     return Band(
-        ds, 
-        bidx, 
+        ds,
+        bidx,
         set(ds.dtypes).pop(),
         ds.shape)
 
 
 def pad(array, transform, pad_width, mode=None, **kwargs):
-    """Returns a padded array and shifted affine transform matrix.
-    
-    Array is padded using `numpy.pad()`."""
+    """pad array and adjust affine transform matrix.
+
+    Parameters
+    ----------
+    array: ndarray
+        Numpy ndarray, for best results a 2D array
+    transform: Affine transform
+        transform object mapping pixel space to coordinates
+    pad_width: int
+        number of pixels to pad array on all four
+    mode: str or function
+        define the method for determining padded values
+
+    Returns
+    -------
+    (array, transform): tuple
+        Tuple of new array and affine transform
+
+    Notes
+    -----
+    See numpy docs for details on mode and other kwargs:
+    http://docs.scipy.org/doc/numpy-1.10.0/reference/generated/numpy.pad.html
+    """
     import numpy
     transform = guard_transform(transform)
     padded_array = numpy.pad(array, pad_width, mode, **kwargs)
@@ -175,80 +283,23 @@ def pad(array, transform, pad_width, mode=None, **kwargs):
 
 
 def get_data_window(arr, nodata=None):
-    """
-    Returns a window for the non-nodata pixels within the input array.
-
-    Parameters
-    ----------
-    arr: numpy ndarray, <= 3 dimensions
-    nodata: number
-        If None, will either return a full window if arr is not a masked
-        array, or will use the mask to determine non-nodata pixels.
-        If provided, it must be a number within the valid range of the dtype
-        of the input array.
-
-    Returns
-    -------
-    ((row_start, row_stop), (col_start, col_stop))
-
-    """
-
-    from rasterio._io import get_data_window
-    return get_data_window(arr, nodata)
+    import warnings
+    warnings.warn("Deprecated; Use rasterio.windows instead", DeprecationWarning)
+    return windows.get_data_window(arr, nodata)
 
 
-def window_union(windows):
-    """
-    Union windows and return the outermost extent they cover.
-
-    Parameters
-    ----------
-    windows: list-like of window objects
-        ((row_start, row_stop), (col_start, col_stop))
-
-    Returns
-    -------
-    ((row_start, row_stop), (col_start, col_stop))
-    """
-
-    from rasterio._io import window_union
-    return window_union(windows)
+def window_union(data):
+    import warnings
+    warnings.warn("Deprecated; Use rasterio.windows instead", DeprecationWarning)
+    return windows.union(data)
 
 
-def window_intersection(windows):
-    """
-    Intersect windows and return the innermost extent they cover.
+def window_intersection(data):
+    import warnings
+    warnings.warn("Deprecated; Use rasterio.windows instead", DeprecationWarning)
+    return windows.intersection(data)
 
-    Will raise ValueError if windows do not intersect.
-
-    Parameters
-    ----------
-    windows: list-like of window objects
-        ((row_start, row_stop), (col_start, col_stop))
-
-    Returns
-    -------
-    ((row_start, row_stop), (col_start, col_stop))
-    """
-
-    from rasterio._io import window_intersection
-    return window_intersection(windows)
-
-
-def windows_intersect(windows):
-    """
-    Test if windows intersect.
-
-    Parameters
-    ----------
-    windows: list-like of window objects
-        ((row_start, row_stop), (col_start, col_stop))
-
-    Returns
-    -------
-    boolean:
-        True if all windows intersect.
-    """
-
-    from rasterio._io import windows_intersect
-    return windows_intersect(windows)
+def windows_intersect(data):
+    import warnings
+    warnings.warn("Deprecated; Use rasterio.windows instead", DeprecationWarning)
+    return windows.intersect(data)
