@@ -91,19 +91,23 @@ def file_in_handler(ctx, param, value):
     except ValueError as exc:
         raise click.BadParameter(str(exc))
     path_to_check = archive or path
-    if not os.path.exists(path_to_check):
+    if not scheme in ['http', 'https', 's3'] and not os.path.exists(path_to_check):
         raise click.BadParameter(
             "Input file {0} does not exist".format(path_to_check))
     if archive and scheme:
         archive = os.path.abspath(archive)
         path = "{0}://{1}!{2}".format(scheme, archive, path)
+    elif scheme and scheme.startswith('http'):
+        path = "{0}://{1}".format(scheme, path)
+    elif scheme == 's3':
+        path = "{0}://{1}".format(scheme, path)
     else:
         path = os.path.abspath(path)
     return path
 
 
 def from_like_context(ctx, param, value):
-    """Return the value for an option from the context if the option 
+    """Return the value for an option from the context if the option
     or `--all` is given, else return None."""
     if ctx.obj and ctx.obj.get('like') and (
             value == 'like' or ctx.obj.get('all_like')):
@@ -215,7 +219,7 @@ creation_options = click.option(
          "more information.")
 
 rgb_opt = click.option(
-    '--rgb', 'photometric', 
+    '--rgb', 'photometric',
     flag_value='rgb',
     default=False,
     help="Set RGB photometric interpretation.")
@@ -236,3 +240,11 @@ like_opt = click.option(
     is_eager=True,
     help="Raster dataset to use as a template for obtaining affine "
          "transform (bounds and resolution), crs, and nodata values.")
+
+all_touched_opt = click.option(
+    '-a', '--all', '--all_touched', 'all_touched',
+    is_flag=True,
+    default=False,
+    help='Use all pixels touched by features, otherwise (default) use only '
+         'pixels whose center is within the polygon or that are selected by '
+         'Bresenhams line algorithm')
