@@ -9,6 +9,8 @@ import pytest
 
 import rasterio
 from rasterio.rio import info
+from rasterio.rio.edit_info import (edit, all_handler, crs_handler,
+                                    tags_handler, transform_handler)
 from rasterio.rio.main import main_group
 
 
@@ -18,14 +20,14 @@ logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 def test_edit_nodata_err(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--nodata', '-1'])
+    result = runner.invoke(edit, [inputfile, '--nodata', '-1'])
     assert result.exit_code == 2
 
 
 def test_edit_nodata(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--nodata', '255'])
+    result = runner.invoke(edit, [inputfile, '--nodata', '255'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.nodata == 255.0
@@ -34,14 +36,14 @@ def test_edit_nodata(data):
 def test_edit_crs_err(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--crs', 'LOL:WUT'])
+    result = runner.invoke(edit, [inputfile, '--crs', 'LOL:WUT'])
     assert result.exit_code == 2
 
 
 def test_edit_crs_epsg(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--crs', 'EPSG:32618'])
+    result = runner.invoke(edit, [inputfile, '--crs', 'EPSG:32618'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.crs == {'init': 'epsg:32618'}
@@ -50,7 +52,7 @@ def test_edit_crs_epsg(data):
 def test_edit_crs_proj4(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--crs', '+init=epsg:32618'])
+    result = runner.invoke(edit, [inputfile, '--crs', '+init=epsg:32618'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.crs == {'init': 'epsg:32618'}
@@ -60,7 +62,7 @@ def test_edit_crs_obj(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
     result = runner.invoke(
-        info.edit, [inputfile, '--crs', '{"init": "epsg:32618"}'])
+        edit, [inputfile, '--crs', '{"init": "epsg:32618"}'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.crs == {'init': 'epsg:32618'}
@@ -69,14 +71,14 @@ def test_edit_crs_obj(data):
 def test_edit_transform_err_not_json(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--transform', 'LOL'])
+    result = runner.invoke(edit, [inputfile, '--transform', 'LOL'])
     assert result.exit_code == 2
 
 
 def test_edit_transform_err_bad_array(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [inputfile, '--transform', '[1,2]'])
+    result = runner.invoke(edit, [inputfile, '--transform', '[1,2]'])
     assert result.exit_code == 2
 
 
@@ -84,7 +86,7 @@ def test_edit_transform_affine(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
     input_t = '[300.038, 0.0, 101985.0, 0.0, -300.042, 2826915.0]'
-    result = runner.invoke(info.edit, [inputfile, '--transform', input_t])
+    result = runner.invoke(edit, [inputfile, '--transform', input_t])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         for a, b in zip(src.affine, json.loads(input_t)):
@@ -95,7 +97,7 @@ def test_edit_transform_gdal(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
     input_t = '[300.038, 0.0, 101985.0, 0.0, -300.042, 2826915.0]'
-    result = runner.invoke(info.edit, [
+    result = runner.invoke(edit, [
         inputfile,
         '--transform', '[101985.0, 300.038, 0.0, 2826915.0, 0.0, -300.042]'])
     assert result.exit_code == 0
@@ -107,7 +109,7 @@ def test_edit_transform_gdal(data):
 def test_edit_tags(data):
     runner = CliRunner()
     inputfile = str(data.join('RGB.byte.tif'))
-    result = runner.invoke(info.edit, [
+    result = runner.invoke(edit, [
         inputfile, '--tag', 'lol=1', '--tag', 'wut=2'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
@@ -130,64 +132,64 @@ class MockOption:
 def test_all_callback_pass(data):
     ctx = MockContext()
     ctx.obj['like'] = {'transform': 'foo'}
-    assert info.all_handler(ctx, None, None) == None
+    assert all_handler(ctx, None, None) == None
 
 
 def test_all_callback(data):
     ctx = MockContext()
     ctx.obj['like'] = {'transform': 'foo'}
-    assert info.all_handler(ctx, None, True) == {'transform': 'foo'}
+    assert all_handler(ctx, None, True) == {'transform': 'foo'}
 
 
 def test_all_callback_None(data):
     ctx = MockContext()
-    assert info.all_handler(ctx, None, None) is None
+    assert all_handler(ctx, None, None) is None
 
 
 def test_transform_callback_pass(data):
     """Always return None if the value is None"""
     ctx = MockContext()
     ctx.obj['like'] = {'transform': 'foo'}
-    assert info.transform_handler(ctx, MockOption('transform'), None) is None
+    assert transform_handler(ctx, MockOption('transform'), None) is None
 
 
 def test_transform_callback_err(data):
     ctx = MockContext()
     ctx.obj['like'] = {'transform': 'foo'}
     with pytest.raises(click.BadParameter):
-        info.transform_handler(ctx, MockOption('transform'), '?')
+        transform_handler(ctx, MockOption('transform'), '?')
 
 
 def test_transform_callback(data):
     ctx = MockContext()
     ctx.obj['like'] = {'transform': 'foo'}
-    assert info.transform_handler(ctx, MockOption('transform'), 'like') == 'foo'
+    assert transform_handler(ctx, MockOption('transform'), 'like') == 'foo'
 
 
 def test_crs_callback_pass(data):
     """Always return None if the value is None"""
     ctx = MockContext()
     ctx.obj['like'] = {'crs': 'foo'}
-    assert info.crs_handler(ctx, MockOption('crs'), None) is None
+    assert crs_handler(ctx, MockOption('crs'), None) is None
 
 
 def test_crs_callback(data):
     ctx = MockContext()
     ctx.obj['like'] = {'crs': 'foo'}
-    assert info.crs_handler(ctx, MockOption('crs'), 'like') == 'foo'
+    assert crs_handler(ctx, MockOption('crs'), 'like') == 'foo'
 
 
 def test_tags_callback_err(data):
     ctx = MockContext()
     ctx.obj['like'] = {'tags': {'foo': 'bar'}}
     with pytest.raises(click.BadParameter):
-        info.tags_handler(ctx, MockOption('tags'), '?') == {'foo': 'bar'}
+        tags_handler(ctx, MockOption('tags'), '?') == {'foo': 'bar'}
 
 
 def test_tags_callback(data):
     ctx = MockContext()
     ctx.obj['like'] = {'tags': {'foo': 'bar'}}
-    assert info.tags_handler(ctx, MockOption('tags'), 'like') == {'foo': 'bar'}
+    assert tags_handler(ctx, MockOption('tags'), 'like') == {'foo': 'bar'}
 
 
 def test_edit_crs_like(data):
@@ -206,8 +208,9 @@ def test_edit_crs_like(data):
 
     # The test.
     templatefile = 'tests/data/RGB.byte.tif'
-    result = runner.invoke(info.edit, [
-        inputfile, '--like', templatefile, '--crs', 'like'])
+    result = runner.invoke(
+        main_group,
+        ['edit-info', inputfile, '--like', templatefile, '--crs', 'like'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.crs == {'init': 'epsg:32618'}
@@ -230,8 +233,9 @@ def test_edit_nodata_like(data):
 
     # The test.
     templatefile = 'tests/data/RGB.byte.tif'
-    result = runner.invoke(info.edit, [
-        inputfile, '--like', templatefile, '--nodata', 'like'])
+    result = runner.invoke(
+        main_group,
+        ['edit-info', inputfile, '--like', templatefile, '--nodata', 'like'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.crs == {'init': 'epsg:32617'}
@@ -252,8 +256,8 @@ def test_edit_all_like(data):
         assert src.nodata == 1.0
 
     templatefile = 'tests/data/RGB.byte.tif'
-    result = runner.invoke(info.edit, [
-        inputfile, '--like', templatefile, '--all'])
+    result = runner.invoke(
+        main_group, ['edit-info', inputfile, '--like', templatefile, '--all'])
     assert result.exit_code == 0
     with rasterio.open(inputfile) as src:
         assert src.crs == {'init': 'epsg:32618'}
@@ -273,16 +277,14 @@ def test_env():
 def test_info_err():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests'])
+        main_group, ['info', 'tests'])
     assert result.exit_code == 1
 
 
 def test_info():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests/data/RGB.byte.tif'])
+        main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"count": 3' in result.output
 
@@ -310,8 +312,7 @@ def test_info_quiet():
 def test_info_count():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests/data/RGB.byte.tif', '--count'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--count'])
     assert result.exit_code == 0
     assert result.output == '3\n'
 
@@ -319,8 +320,7 @@ def test_info_count():
 def test_info_nodatavals():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests/data/RGB.byte.tif', '--bounds'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--bounds'])
     assert result.exit_code == 0
     assert result.output == '101985.0 2611485.0 339315.0 2826915.0\n'
 
@@ -328,8 +328,7 @@ def test_info_nodatavals():
 def test_info_tags():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests/data/RGB.byte.tif', '--tags'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--tags'])
     assert result.exit_code == 0
     assert result.output == '{"AREA_OR_POINT": "Area"}\n'
 
@@ -337,8 +336,7 @@ def test_info_tags():
 def test_info_res():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests/data/RGB.byte.tif', '--res'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--res'])
     assert result.exit_code == 0
     assert result.output.startswith('300.037')
 
@@ -346,15 +344,14 @@ def test_info_res():
 def test_info_lnglat():
     runner = CliRunner()
     result = runner.invoke(
-        info.info,
-        ['tests/data/RGB.byte.tif', '--lnglat'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--lnglat'])
     assert result.exit_code == 0
     assert result.output.startswith('-77.757')
 
 
 def test_mo_info():
     runner = CliRunner()
-    result = runner.invoke(info.info, ['tests/data/RGB.byte.tif'])
+    result = runner.invoke(main_group, ['info', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
     assert '"res": [300.037' in result.output
     assert '"lnglat": [-77.757' in result.output
@@ -363,7 +360,7 @@ def test_mo_info():
 def test_info_stats():
     runner = CliRunner()
     result = runner.invoke(
-        info.info, ['tests/data/RGB.byte.tif', '--tell-me-more'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--tell-me-more'])
     assert result.exit_code == 0
     assert '"max": 255.0' in result.output
     assert '"min": 1.0' in result.output
@@ -373,7 +370,8 @@ def test_info_stats():
 def test_info_stats_only():
     runner = CliRunner()
     result = runner.invoke(
-        info.info, ['tests/data/RGB.byte.tif', '--stats', '--bidx', '2'])
+        main_group,
+        ['info', 'tests/data/RGB.byte.tif', '--stats', '--bidx', '2'])
     assert result.exit_code == 0
     assert result.output.startswith('1.000000 255.000000 66.02')
 
@@ -595,26 +593,20 @@ def test_bounds_seq_rs():
 
 def test_insp():
     runner = CliRunner()
-    result = runner.invoke(main_group, [
-        'insp',
-        'tests/data/RGB.byte.tif'
-    ])
+    result = runner.invoke(main_group, ['insp', 'tests/data/RGB.byte.tif'])
     assert result.exit_code == 0
 
 
 def test_insp_err():
     runner = CliRunner()
-    result = runner.invoke(main_group, [
-        'insp',
-        'tests'
-    ])
+    result = runner.invoke(main_group, ['insp', 'tests'])
     assert result.exit_code == 1
 
 
 def test_info_checksums():
     runner = CliRunner()
     result = runner.invoke(
-        info.info, ['tests/data/RGB.byte.tif', '--tell-me-more'])
+        main_group, ['info', 'tests/data/RGB.byte.tif', '--tell-me-more'])
     assert result.exit_code == 0
     assert '"checksum": [25420, 29131, 37860]' in result.output
 
@@ -622,6 +614,7 @@ def test_info_checksums():
 def test_info_checksums_only():
     runner = CliRunner()
     result = runner.invoke(
-        info.info, ['tests/data/RGB.byte.tif', '--checksum', '--bidx', '2'])
+        main_group,
+        ['info', 'tests/data/RGB.byte.tif', '--checksum', '--bidx', '2'])
     assert result.exit_code == 0
     assert result.output.strip() == '29131'
